@@ -34,6 +34,12 @@ class IBridge(ABC):
     def isoDate(self):
         pass
     @abstractmethod
+    def runBackgroundTask(self,task):
+        pass
+    @abstractmethod
+    def toISOString(self,seconds):
+        pass
+    @abstractmethod
     def jwtSign(self,payload,privateKey,algorithm):
         pass
     @abstractmethod
@@ -48,6 +54,3 @@ class IBridge(ABC):
     @abstractmethod
     def getObjectKeys(self,obj):
         pass
-    @abstractmethod
-    def getRouter(self):
-        pass
