@@ -4,7 +4,8 @@ import aiohttp
 import jwt
 import time
 import uuid
-from datetime import datetime
+import asyncio
+from datetime import datetime, timedelta
 from nerualpha.IBridge import IBridge
 
 class Bridge(IBridge):
@@ -47,6 +48,10 @@ class Bridge(IBridge):
             print("Exception in request")
             raise e
 
+    def runBackgroundTask(self, task):
+        loop = asyncio.get_event_loop()
+        loop.create_task(task)
+
     async def requestWithoutResponse(self,params):
         await self.request(params)
     def uuid(self):
@@ -54,6 +59,9 @@ class Bridge(IBridge):
     def isoDate(self):
         my_date = datetime.now()
         return my_date.isoformat()
+    def toISOString(self,seconds):
+        my_date = datetime.now() + timedelta(seconds=seconds)
+        return my_date.isoformat()
     def jwtSign(self,payload,privateKey,algorithm):
         return jwt.encode({
             'api_application_id': payload.api_application_id,
@@ -71,5 +79,3 @@ class Bridge(IBridge):
         print(logAction)
     def getObjectKeys(self,obj):
         return obj.keys()
-    def getRouter(self):
-        pass
