@@ -11,9 +11,7 @@ from nerualpha.services.config.config import Config
 from nerualpha.request.IRequest import IRequest
 from nerualpha.providers.state.state import State
 from nerualpha.services.jwt.IJwt import IJWT
-from nerualpha.session.ISession import ISession
 from nerualpha.INeru import INeru
-from nerualpha.providers.state.IState import IState
 from nerualpha.services.commandService.ICommandService import ICommandService
 from nerualpha.services.commandService.commandService import CommandService
 
@@ -29,9 +27,11 @@ class Neru(INeru):
         self.jwt = JWT(self.bridge,self.config)
         self.commandService = CommandService(self.bridge)
     
-    def createSession(self):
+    def createSession(self,ttl = 7 * 24 * 60 * 60):
         id = self.bridge.uuid()
-        return self.createSessionWithId(id)
+        session = self.createSessionWithId(id)
+        self.bridge.runBackgroundTask(session.emitSessionCreatedEvent(ttl))
+        return session
     
     def createSessionWithId(self,id):
         return NeruSession(self.commandService,self.bridge,self.config,self.jwt,id)
@@ -42,9 +42,6 @@ class Neru(INeru):
         
         return self.createSessionWithId(id)
     
-    def Router(self):
-        return self.bridge.getRouter()
-    
     def getAppUrl(self):
         return self.config.appUrl
     
