@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.assets.IGetAssetLinkPayload import IGetAssetLinkPayload
+from nerualpha.providers.assets.IGetAssetLinkPayload import IGetAssetLinkPayload
 
 @dataclass
 class GetAssetLinkPayload(IGetAssetLinkPayload):
