@@ -2,15 +2,15 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.session.requestInterface import RequestInterface
-from src.session.requestInterfaceForCallbacks import RequestInterfaceForCallbacks
-from src.providers.vonageAPI.contracts.invokePayload import InvokePayload
-from src.providers.messages.contracts.IBaseMessage import IBaseMessage
-from src.providers.messages.contracts.IMessageContact import IMessageContact
-from src.providers.messages.contracts.ISendImageContent import ISendImageContent
-from src.providers.messages.contracts.sendImagePayload import SendImagePayload
-from src.providers.messages.contracts.sendTextPayload import SendTextPayload
-from src.providers.messages.contracts.unsubscribeEventsPayload import UnsubscribeEventsPayload
+from nerualpha.session.requestInterface import RequestInterface
+from nerualpha.session.requestInterfaceForCallbacks import RequestInterfaceForCallbacks
+from nerualpha.providers.vonageAPI.contracts.invokePayload import InvokePayload
+from nerualpha.providers.messages.contracts.IBaseMessage import IBaseMessage
+from nerualpha.providers.messages.contracts.IMessageContact import IMessageContact
+from nerualpha.providers.messages.contracts.ISendImageContent import ISendImageContent
+from nerualpha.providers.messages.contracts.sendImagePayload import SendImagePayload
+from nerualpha.providers.messages.contracts.sendTextPayload import SendTextPayload
+from nerualpha.providers.messages.contracts.unsubscribeEventsPayload import UnsubscribeEventsPayload
 
 
 #interface
