@@ -2,9 +2,9 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.messages.contracts.IListenEventsPayload import IListenEventsPayload
-from src.providers.messages.contracts.IMessageContact import IMessageContact
-from src.session.IWrappedCallback import IWrappedCallback
+from nerualpha.providers.messages.contracts.IListenEventsPayload import IListenEventsPayload
+from nerualpha.providers.messages.contracts.IMessageContact import IMessageContact
+from nerualpha.session.IWrappedCallback import IWrappedCallback
 
 @dataclass
 class ListenEventsPayload(IListenEventsPayload):
