@@ -8,10 +8,10 @@ from nerualpha.providers.messages.contracts.IMMSImageMessage import IMMSImageMes
 @dataclass
 class MMSImageMessage(IMMSImageMessage):
     to: str
-    message_type: str
     from_: str
-    channel: str
     image: IImagePayload
+    channel: str = field(default = "mms")
+    message_type: str = field(default = "image")
     def __init__(self):
         pass
     def reprJSON(self):
