@@ -4,7 +4,7 @@ from abc import ABC, abstractmethod
 
 from nerualpha.session.requestInterface import RequestInterface
 from nerualpha.session.requestInterfaceForCallbacks import RequestInterfaceForCallbacks
-from nerualpha.providers.scheduler.contracts.cancelSchedulePayload import CancelSchedulePayload
+from nerualpha.providers.scheduler.contracts.schedulePayload import SchedulePayload
 from nerualpha.providers.scheduler.contracts.IStartAtParams import IStartAtParams
 
 
