@@ -2,9 +2,9 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.session.IWrappedCallback import IWrappedCallback
-from src.providers.scheduler.contracts.IIntervalParams import IIntervalParams
-from src.providers.scheduler.contracts.IStartAtPayload import IStartAtPayload
+from nerualpha.session.IWrappedCallback import IWrappedCallback
+from nerualpha.providers.scheduler.contracts.IIntervalParams import IIntervalParams
+from nerualpha.providers.scheduler.contracts.IStartAtPayload import IStartAtPayload
 
 T = TypeVar("T")
 
