@@ -7,7 +7,7 @@ from nerualpha.providers.scheduler.schedulerActions import SchedulerActions
 from nerualpha.session.actionPayload import ActionPayload
 from nerualpha.providers.scheduler.IScheduler import IScheduler
 from nerualpha.providers.scheduler.contracts.startAtPayload import StartAtPayload
-from nerualpha.providers.scheduler.contracts.cancelSchedulePayload import CancelSchedulePayload
+from nerualpha.providers.scheduler.contracts.schedulePayload import SchedulePayload
 from nerualpha.providers.scheduler.contracts.IStartAtParams import IStartAtParams
 from nerualpha.session.ISession import ISession
 from nerualpha.session.requestInterfaceForCallbacks import RequestInterfaceForCallbacks
@@ -33,11 +33,20 @@ class Scheduler(IScheduler):
         if params.id is not None:
             startAtPayload.id = params.id
         
-        action = ActionPayload(self.provider,SchedulerActions.create,startAtPayload)
+        action = ActionPayload(self.provider,SchedulerActions.Create,startAtPayload)
         return RequestInterfaceForCallbacks(self.session,action)
     
+    def listAll(self):
+        action = ActionPayload(self.provider,SchedulerActions.List,None)
+        return RequestInterface(self.session,action)
+    
+    def get(self,scheduleId):
+        payload = SchedulePayload(scheduleId)
+        action = ActionPayload(self.provider,SchedulerActions.Get,payload)
+        return RequestInterface(self.session,action)
+    
     def cancel(self,scheduleId):
-        payload = CancelSchedulePayload(scheduleId)
+        payload = SchedulePayload(scheduleId)
         action = ActionPayload(self.provider,SchedulerActions.Cancel,payload)
         return RequestInterface(self.session,action)
     
