@@ -18,10 +18,15 @@ class State(IState):
     url: str
     namespace: str
     provider: str = field(default = "client-persistence-api")
-    def __init__(self,session,namespace):
+    def __init__(self,session,namespace = None):
         self.bridge = session.bridge
         self.url = session.config.getExecutionUrl(self.provider)
-        self.namespace = namespace
+        if namespace is None:
+            self.namespace = f'state:{session.id}'
+        
+        else: 
+            self.namespace = namespace
+        
         self.session = session
         self.commandService = session.commandService
     
@@ -64,7 +69,7 @@ class State(IState):
         response = await self.executeCommand(command)
         result = {}
         for i in range(0,response.count,2):
-            result[response[i]] = self.bridge.jsonParse(response[i + 1])
+            result[response[i]] = response[i + 1]
         
         return result
     
@@ -73,7 +78,7 @@ class State(IState):
         response = await self.executeCommand(command)
         result = []
         for i in range(0,response.count):
-            result.append(self.bridge.jsonParse(response[i]))
+            result.append(response[i])
         
         return result
     
@@ -83,7 +88,7 @@ class State(IState):
         response = await self.executeCommand(command)
         result = []
         for i in range(0,response.count):
-            result.append(self.bridge.jsonParse(response[i]))
+            result.append(response[i])
         
         return result
     
@@ -91,7 +96,7 @@ class State(IState):
         payload = [key]
         command = self.createCommand(StateOperations.HGET,htable,payload)
         result = await self.executeCommand(command)
-        return self.bridge.jsonParse(result)
+        return result
     
     async def hset(self,htable,keyValuePairs):
         payload = []
