@@ -41,7 +41,7 @@ class IConversation(ABC):
     def deleteMember(self,memberId):
         pass
     @abstractmethod
-    def sayText(self,body):
+    def sayText(self,body,to):
         pass
     @abstractmethod
     def sayStop(self,sayId,to = None):
