@@ -33,5 +33,5 @@ class IVoice(ABC):
     def uploadNCCO(self,uuid,ncco):
         pass
     @abstractmethod
-    def getConversation(self,id,name):
+    def getConversation(self,id):
         pass
