@@ -3,7 +3,7 @@ from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
 from nerualpha.providers.voice.contracts.IAcceptInboundCallEndpoint import IAcceptInboundCallEndpoint
-from nerualpha.providers.voice.contracts.ILegId import ILegId
+from nerualpha.providers.voice.contracts.ILeg import ILeg
 
 
 #interface
@@ -12,4 +12,4 @@ class IAcceptInboundCallChannel(ABC):
     leg_id:str
     from_:IAcceptInboundCallEndpoint
     to:IAcceptInboundCallEndpoint
-    leg_ids:List[ILegId]
+    leg_ids:List[ILeg]
