@@ -7,5 +7,5 @@ from nerualpha.session.IPayloadWithCallback import IPayloadWithCallback
 
 #interface
 class IVapiEventCallBackPayload(IPayloadWithCallback):
-    vapiId:str
+    vapiID:str
     conversationID:str
