@@ -4,11 +4,11 @@ from abc import ABC, abstractmethod
 
 from nerualpha.providers.voice.contracts.IAcceptInboundCallChannel import IAcceptInboundCallChannel
 from nerualpha.providers.voice.contracts.IAcceptInboundCallEndpoint import IAcceptInboundCallEndpoint
-from nerualpha.providers.voice.contracts.ILegId import ILegId
+from nerualpha.providers.voice.contracts.ILeg import ILeg
 
 @dataclass
 class AcceptInboundCallChannel(IAcceptInboundCallChannel):
-    leg_ids: List[ILegId]
+    leg_ids: List[ILeg]
     to: IAcceptInboundCallEndpoint
     from_: IAcceptInboundCallEndpoint
     leg_id: str
