@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.voice.contracts.IAddUserPayload import IAddUserPayload
+from nerualpha.providers.voice.contracts.IAddUserPayload import IAddUserPayload
 
 @dataclass
 class AddUserPayload(IAddUserPayload):
