@@ -2,8 +2,8 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.voice.contracts.INeruPayloadWithCallback import INeruPayloadWithCallback
-from src.session.IWrappedCallback import IWrappedCallback
+from nerualpha.providers.voice.contracts.INeruPayloadWithCallback import INeruPayloadWithCallback
+from nerualpha.session.IWrappedCallback import IWrappedCallback
 
 @dataclass
 class NeruPayloadWithCallback(INeruPayloadWithCallback):
