@@ -21,7 +21,6 @@ from nerualpha.providers.voice.contracts.playStreamPayload import PlayStreamPayl
 from nerualpha.providers.voice.contracts.playStopPayload import PlayStopPayload
 from nerualpha.providers.voice.contracts.reason import Reason
 from nerualpha.providers.voice.contracts.deleteMemberPayload import DeleteMemberPayload
-from nerualpha.providers.voice.contracts.ISayTextBody import ISayTextBody
 from nerualpha.providers.voice.contracts.sayTextPayload import SayTextPayload
 from nerualpha.providers.voice.contracts.earmuffPayload import EarmuffPayload
 from nerualpha.providers.voice.contracts.audioSettings import AudioSettings
@@ -35,6 +34,7 @@ from nerualpha.providers.voice.contracts.mutePayload import MutePayload
 from nerualpha.providers.voice.contracts.neruPayloadWithCallback import NeruPayloadWithCallback
 from nerualpha.providers.voice.contracts.addUserPayload import AddUserPayload
 from nerualpha.session.IPayloadWithCallback import IPayloadWithCallback
+from nerualpha.providers.voice.contracts.ISayTextBody import ISayTextBody
 
 @dataclass
 class Conversation(IConversation):
@@ -44,9 +44,8 @@ class Conversation(IConversation):
     name: str
     id: str
     provider: str = field(default = "vonage-voice")
-    def __init__(self,id,name,session):
+    def __init__(self,id,session):
         self.id = id
-        self.name = name
         self.session = session
         self.vonageAPI = VonageAPI(self.session)
         self.baseUrl = "https://api.nexmo.com/v0.3"
@@ -89,8 +88,23 @@ class Conversation(IConversation):
         method = f'PATCH'
         return self.vonageAPI.invoke(url,method,payload)
     
-    def sayText(self,params):
-        payload = SayTextPayload(params)
+    def sayText(self,body,to = None):
+        if body.level is None:
+            body.level = 1
+        
+        if body.loop is None:
+            body.loop = 1
+        
+        if body.voice_name is None:
+            body.voice_name = "Amy"
+        
+        if body.queue is None:
+            body.queue = False
+        
+        if body.ssml is None:
+            body.ssml = False
+        
+        payload = SayTextPayload(body,to)
         method = "POST"
         url = f'{self.baseUrl}/conversations/{self.id}/events'
         return self.vonageAPI.invoke(url,method,payload)
@@ -102,6 +116,12 @@ class Conversation(IConversation):
         return self.vonageAPI.invoke(url,method,payload)
     
     def playStream(self,body,to = None):
+        if body.loop is None:
+            body.loop = 1
+        
+        if body.level is None:
+            body.level = 1
+        
         payload = PlayStreamPayload(body,to)
         url = f'{self.baseUrl}/conversations/{self.id}/events'
         method = "POST"
