@@ -19,7 +19,6 @@ from nerualpha.providers.voice.contracts.createConversationPayload import Create
 from nerualpha.providers.voice.contracts.IChannelPhoneEndpoint import IChannelPhoneEndpoint
 from nerualpha.providers.voice.contracts.vapiAnswerCallBack import VapiAnswerCallBack
 from nerualpha.providers.voice.contracts.vapiEventCallBackPayload import VapiEventCallBackPayload
-from nerualpha.providers.voice.contracts.IVapiCreateCallPayload import IVapiCreateCallPayload
 from nerualpha.providers.voice.contracts.vapiCreateCallPayload import VapiCreateCallPayload
 from nerualpha.providers.voice.contracts.onInboundCallPayload import OnInboundCallPayload
 from nerualpha.IBridge import IBridge
@@ -46,25 +45,20 @@ class Voice(IVoice):
         return RequestInterfaceForCallbacks(self.session,action)
     
     async def createConversation(self,name = None,displayName = None):
-        try:
-            conversationName = name
-            conversationDisplayName = displayName
-            if name is None:
-                conversationId = self.bridge.substring(self.session.createUUID(),0,5)
-                conversationName = f'name_cs_{conversationId}'
-            
-            if displayName is None:
-                conversationDisplayName = f'dn_{name};'
-            
-            payload = CreateConversationPayload(name,displayName)
-            url = "https://api.nexmo.com/v0.3/conversations"
-            method = "POST"
-            res = await self.vonageApi.invoke(url,method,payload).execute()
-            return Conversation(res.id,name,self.session)
+        conversationName = name
+        conversationDisplayName = displayName
+        if name is None:
+            conversationId = self.bridge.substring(self.session.createUUID(),0,5)
+            conversationName = f'name_cs_{conversationId}'
         
-        except Exception as err:
-            raise Exception(err)
+        if displayName is None:
+            conversationDisplayName = f'dn_{conversationName};'
         
+        payload = CreateConversationPayload(conversationName,conversationDisplayName)
+        url = "https://api.nexmo.com/v0.3/conversations"
+        method = "POST"
+        res = await self.vonageApi.invoke(url,method,payload).execute()
+        return Conversation(res.id,self.session)
     
     def onVapiAnswer(self,callback):
         payload = VapiAnswerCallBack(self.session.wrapCallback(callback,[]))
@@ -74,8 +68,11 @@ class Voice(IVoice):
     def onVapiEvent(self,params):
         payload = VapiEventCallBackPayload()
         payload.callback = self.session.wrapCallback(params.callback,[])
+        if params.conversationID is None and params.vapiUUID is None:
+            raise Exception("Either conversationID or vapiUUID is required")
+        
         if params.vapiUUID is not None:
-            payload.vapiId = params.vapiUUID
+            payload.vapiID = params.vapiUUID
         
         elif params.conversationID is not None:
             payload.conversationID = params.conversationID
@@ -90,8 +87,8 @@ class Voice(IVoice):
     def uploadNCCO(self,uuid,ncco):
         return self.vonageApi.invoke(f'{self.regionURL}/v1/calls/{uuid}',"PUT",ncco)
     
-    def getConversation(self,id,name):
-        return Conversation(id,name,self.session)
+    def getConversation(self,id):
+        return Conversation(id,self.session)
     
     def reprJSON(self):
         dict = {}
