@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.vonageAPI.contracts.IInvokePayload import IInvokePayload
+from nerualpha.providers.vonageAPI.contracts.IInvokePayload import IInvokePayload
 
 T = TypeVar("T")
 
