@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.IBridge import IBridge
+from nerualpha.IBridge import IBridge
 
 
 #interface
