@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.session.ICommandHeaders import ICommandHeaders
+from nerualpha.session.ICommandHeaders import ICommandHeaders
 
 @dataclass
 class CommandHeaders(ICommandHeaders):
