@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.session.IFilter import IFilter
+from nerualpha.session.IFilter import IFilter
 
 @dataclass
 class Filter(IFilter):
