@@ -3,6 +3,8 @@ from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
 from nerualpha.IBridge import IBridge
+from nerualpha.providers.events.eventEmitter import EventEmitter
+from nerualpha.providers.events.IEventEmitter import IEventEmitter
 from nerualpha.providers.logger.ILogContext import ILogContext
 from nerualpha.providers.logger.ILogger import ILogger
 from nerualpha.providers.logger.logContext import LogContext
@@ -22,6 +24,7 @@ from nerualpha.session.wrappedCallback import WrappedCallback
 
 @dataclass
 class NeruSession(ISession):
+    eventEmitter: IEventEmitter
     commandService: ICommandService
     logger: ILogger
     bridge: IBridge
@@ -34,8 +37,12 @@ class NeruSession(ISession):
         self.bridge = bridge
         self.config = config
         self.jwt = jwt
+        self.eventEmitter = EventEmitter(self)
         self.logger = Logger(self)
     
+    async def emitSessionCreatedEvent(self,ttl):
+        await self.eventEmitter.emitSessionCreatedEvent(ttl)
+    
     def createUUID(self):
         return self.bridge.uuid()
     
@@ -45,13 +52,8 @@ class NeruSession(ISession):
         
         return self.jwt.getToken()
     
-    async def log(self,level,message,context = None):
-        try:
-            await self.logger.log(level,message,context)
-        
-        except Exception as e:
-            raise Exception("Error during sending logs:" + e)
-        
+    def log(self,level,message,context = None):
+        self.bridge.runBackgroundTask(self.logger.log(level,message,context))
     
     def wrapCallback(self,route,filters):
         wrappedCallback = WrappedCallback()
@@ -95,13 +97,13 @@ class NeruSession(ISession):
             url = self.config.getExecutionUrl(actionPayload.provider)
             result = await self.commandService.executeCommand(url,payload,requestHeaders)
             context = LogContext(actionPayload.action,self.bridge.jsonStringify(actionPayload.payload),self.bridge.jsonStringify(result))
-            await self.logger.log(LogLevels.info,f'Executing action: {actionPayload.action}, provider: {actionPayload.provider}',context)
+            self.log(LogLevels.info,f'Executing action: {actionPayload.action}, provider: {actionPayload.provider}',context)
             return result
         
         except Exception as e:
-            context = LogContext(actionPayload.action,self.bridge.jsonStringify(actionPayload.payload),e)
-            await self.log(LogLevels.error,f'Error while executing action: {actionPayload.action}, provider: {actionPayload.provider}',context)
-            raise Exception(e)
+            context = LogContext(actionPayload.action,self.bridge.jsonStringify(actionPayload.payload),e.message)
+            self.log(LogLevels.error,f'Error while executing action: {actionPayload.action}, provider: {actionPayload.provider}',context)
+            raise e
         
     
     def reprJSON(self):
