@@ -2,8 +2,8 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.webhookEvents.IUrlObject import IUrlObject
-from src.webhookEvents.messenger.IMessengerImageEvent import IMessengerImageEvent
+from nerualpha.webhookEvents.IUrlObject import IUrlObject
+from nerualpha.webhookEvents.messenger.IMessengerImageEvent import IMessengerImageEvent
 
 @dataclass
 class MessengerImageEvent(IMessengerImageEvent):
