@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.webhookEvents.messenger.IMessengerUnsupportedEvent import IMessengerUnsupportedEvent
+from nerualpha.webhookEvents.messenger.IMessengerUnsupportedEvent import IMessengerUnsupportedEvent
 
 @dataclass
 class MessengerUnsupportedEvent(IMessengerUnsupportedEvent):
