@@ -3,6 +3,8 @@ from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
 from nerualpha.webhookEvents.IUrlObject import IUrlObject
+from nerualpha.webhookEvents.whatsapp.IMessageEventContext import IMessageEventContext
+from nerualpha.webhookEvents.whatsapp.IProfileName import IProfileName
 from nerualpha.webhookEvents.whatsapp.IWhatsappVideoEvent import IWhatsappVideoEvent
 
 @dataclass
@@ -10,10 +12,13 @@ class WhatsappVideoEvent(IWhatsappVideoEvent):
     to: str
     timestamp: str
     message_uuid: str
-    message_type: str
     from_: str
     channel: str
+    message_type: str
     video: IUrlObject
+    profile: IProfileName = None
+    context: IMessageEventContext = None
+    provider_message: str = None
     def __init__(self):
         pass
     def reprJSON(self):
